@@ -1,8 +1,10 @@
-from .amatrix import makeA
+from .amatrix import makeA, makeD
 from .gmatrix import makeG
 from .hmatrix import makeH
 from .sort import sortPed
 from .loaddata import loadEgPed, loadEgGeno
 from .selectped import selectPed
 from .plot import cluster, heat,gragh, pca
-from .coef import coefKinship,coefInbreeding
\ No newline at end of file
+from .coef import coefKinship,coefInbreeding
+from .inter_matrix import makeG_inter
+from .mmatrix import makeM
\ No newline at end of file
