@@ -1,6 +1,9 @@
 import os.path
 import pandas as pd
 def loadEgPed():
+    '''Load example pedigree data.
+
+    '''
     basepath = os.path.abspath(__file__)
     folder = os.path.dirname(basepath)
     data_path = os.path.join(folder, 'data/ped.txt')
@@ -8,6 +11,9 @@ def loadEgPed():
 
     return text
 def loadEgGeno():
+    '''Load example genotype data.
+
+    '''
     basepath = os.path.abspath(__file__)
     folder = os.path.dirname(basepath)
     data_path = os.path.join(folder, 'data/geno.traw')
