@@ -1,6 +1,10 @@
 #Ross, E. M., Moate, P. J., Marett, L. C., Cocks, B. G., & Hayes, B. J. (2013). Metagenomic predictions: From microbiome to complex health and environmental phenotypes in humans and cattle. 
 import numpy as np
 def makeM(otu):
+    '''Calculate the kinship matrix using OTU.
+    
+    otu: OTU data in numpy ndarray type. Rows are individuals and columns are OTUs.
+    '''
     ###检测没有空值
     if not isinstance(otu, np.ndarray):
         print("ERROR: OTU matrix should be numpy ndarray")
